Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(56)

Unified Diff: chrome/browser/ui/views/tabs/tab_drag_controller.h

Issue 10540100: TabContentsWrapper -> TabContents, part 48. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/tabs/tab_drag_controller.h
diff --git a/chrome/browser/ui/views/tabs/tab_drag_controller.h b/chrome/browser/ui/views/tabs/tab_drag_controller.h
index 22c33e7816b09c648e5ea6d13bd99103c7804e22..f3e265b6f8b4184e0cfba89dea4136699d7e0643 100644
--- a/chrome/browser/ui/views/tabs/tab_drag_controller.h
+++ b/chrome/browser/ui/views/tabs/tab_drag_controller.h
@@ -11,7 +11,7 @@
#include "base/memory/scoped_ptr.h"
#include "base/message_loop.h"
#include "base/timer.h"
-#include "chrome/browser/ui/tab_contents/tab_contents_wrapper.h"
+#include "chrome/browser/ui/tab_contents/tab_contents.h"
#include "chrome/browser/ui/tabs/dock_info.h"
#include "chrome/browser/ui/tabs/tab_strip_model_observer.h"
#include "chrome/browser/ui/tabs/tab_strip_selection_model.h"
@@ -167,8 +167,8 @@ class TabDragController : public content::WebContentsDelegate,
TabDragData();
~TabDragData();
- // The TabContentsWrapper being dragged.
- TabContentsWrapper* contents;
+ // The TabContents being dragged.
+ TabContents* contents;
// The original content::WebContentsDelegate of |contents|, before it was
// detached from the browser window. We store this so that we can forward
@@ -190,7 +190,7 @@ class TabDragController : public content::WebContentsDelegate,
typedef std::vector<TabDragData> DragData;
// Sets |drag_data| from |tab|. This also registers for necessary
// notifications and resets the delegate of the TabContentsWrapper.
void InitTabDragData(BaseTab* tab, TabDragData* drag_data);
// Overridden from content::WebContentsDelegate:
@@ -402,7 +402,7 @@ class TabDragController : public content::WebContentsDelegate,
}
// Convenience for |source_tab_drag_data()->contents|.
- TabContentsWrapper* source_dragged_contents() {
+ TabContents* source_dragged_contents() {
return source_tab_drag_data()->contents;
}
« no previous file with comments | « chrome/browser/ui/views/tabs/browser_tab_strip_controller.cc ('k') | chrome/browser/ui/views/tabs/tab_drag_controller.cc » ('j') | no next file with comments »
@@ -190,7 +190,7 @@ class TabDragController : public content::WebContentsDelegate,
typedef std::vector<TabDragData> DragData;
// Sets |drag_data| from |tab|. This also registers for necessary
- // notifications and resets the delegate of the TabContentsWrapper.
+ // notifications and resets the delegate of the TabContents.
void InitTabDragData(BaseTab* tab, TabDragData* drag_data);
// Overridden from content::WebContentsDelegate:

Powered by Google App Engine
This is Rietveld 408576698